==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/APIServerConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class APIServerConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent<A>{
  public APIServerConfigFluentImpl() {
  }
  public APIServerConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.APIServerConfig instance) {
    this.withAuthorization(instance.getAuthorization()); 
    this.withBasicAuth(instance.getBasicAuth()); 
    this.withBearerToken(instance.getBearerToken()); 
    this.withBearerTokenFile(instance.getBearerTokenFile()); 
    this.withHost(instance.getHost()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder authorization;
  private io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder basicAuth;
  private java.lang.String bearerToken;
  private java.lang.String bearerTokenFile;
  private java.lang.String host;
  private io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder tlsConfig;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAuthorization instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.Authorization getAuthorization() {
    return this.authorization!=null?this.authorization.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.Authorization buildAuthorization() {
    return this.authorization!=null?this.authorization.build():null;
  }
  public A withAuthorization(io.fabric8.openshift.api.model.monitoring.v1.Authorization authorization) {
    _visitables.get("authorization").remove(this.authorization);
    if (authorization!=null){ this.authorization= new io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder(authorization); _visitables.get("authorization").add(this.authorization);} return (A) this;
  }
  public java.lang.Boolean hasAuthorization() {
    return this.authorization != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> withNewAuthorization() {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.AuthorizationNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> withNewAuthorizationLike(io.fabric8.openshift.api.model.monitoring.v1.Authorization item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.AuthorizationNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> editAuthorization() {
    return withNewAuthorizationLike(getAuthorization());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> editOrNewAuthorization() {
    return withNewAuthorizationLike(getAuthorization() != null ? getAuthorization(): new io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> editOrNewAuthorizationLike(io.fabric8.openshift.api.model.monitoring.v1.Authorization item) {
    return withNewAuthorizationLike(getAuthorization() != null ? getAuthorization(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildBasicAuth instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.BasicAuth getBasicAuth() {
    return this.basicAuth!=null?this.basicAuth.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.BasicAuth buildBasicAuth() {
    return this.basicAuth!=null?this.basicAuth.build():null;
  }
  public A withBasicAuth(io.fabric8.openshift.api.model.monitoring.v1.BasicAuth basicAuth) {
    _visitables.get("basicAuth").remove(this.basicAuth);
    if (basicAuth!=null){ this.basicAuth= new io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder(basicAuth); _visitables.get("basicAuth").add(this.basicAuth);} return (A) this;
  }
  public java.lang.Boolean hasBasicAuth() {
    return this.basicAuth != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> withNewBasicAuth() {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.BasicAuthNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> withNewBasicAuthLike(io.fabric8.openshift.api.model.monitoring.v1.BasicAuth item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.BasicAuthNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> editBasicAuth() {
    return withNewBasicAuthLike(getBasicAuth());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> editOrNewBasicAuth() {
    return withNewBasicAuthLike(getBasicAuth() != null ? getBasicAuth(): new io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> editOrNewBasicAuthLike(io.fabric8.openshift.api.model.monitoring.v1.BasicAuth item) {
    return withNewBasicAuthLike(getBasicAuth() != null ? getBasicAuth(): item);
  }
  public java.lang.String getBearerToken() {
    return this.bearerToken;
  }
  public A withBearerToken(java.lang.String bearerToken) {
    this.bearerToken=bearerToken; return (A) this;
  }
  public java.lang.Boolean hasBearerToken() {
    return this.bearerToken != null;
  }
  
  /**
   * Method is deprecated. use withBearerToken instead.
   */
  @java.lang.Deprecated
  public A withNewBearerToken(java.lang.String arg0) {
    return (A)withBearerToken(new String(arg0));
  }
  public java.lang.String getBearerTokenFile() {
    return this.bearerTokenFile;
  }
  public A withBearerTokenFile(java.lang.String bearerTokenFile) {
    this.bearerTokenFile=bearerTokenFile; return (A) this;
  }
  public java.lang.Boolean hasBearerTokenFile() {
    return this.bearerTokenFile != null;
  }
  
  /**
   * Method is deprecated. use withBearerTokenFile instead.
   */
  @java.lang.Deprecated
  public A withNewBearerTokenFile(java.lang.String arg0) {
    return (A)withBearerTokenFile(new String(arg0));
  }
  public java.lang.String getHost() {
    return this.host;
  }
  public A withHost(java.lang.String host) {
    this.host=host; return (A) this;
  }
  public java.lang.Boolean hasHost() {
    return this.host != null;
  }
  
  /**
   * Method is deprecated. use withHost instead.
   */
  @java.lang.Deprecated
  public A withNewHost(java.lang.String arg0) {
    return (A)withHost(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTlsConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig getTlsConfig() {
    return this.tlsConfig!=null?this.tlsConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig buildTlsConfig() {
    return this.tlsConfig!=null?this.tlsConfig.build():null;
  }
  public A withTlsConfig(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig tlsConfig) {
    _visitables.get("tlsConfig").remove(this.tlsConfig);
    if (tlsConfig!=null){ this.tlsConfig= new io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder(tlsConfig); _visitables.get("tlsConfig").add(this.tlsConfig);} return (A) this;
  }
  public java.lang.Boolean hasTlsConfig() {
    return this.tlsConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> withNewTlsConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.TlsConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> withNewTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.TlsConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> editTlsConfig() {
    return withNewTlsConfigLike(getTlsConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> editOrNewTlsConfig() {
    return withNewTlsConfigLike(getTlsConfig() != null ? getTlsConfig(): new io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> editOrNewTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item) {
    return withNewTlsConfigLike(getTlsConfig() != null ? getTlsConfig(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    APIServerConfigFluentImpl that = (APIServerConfigFluentImpl) o;
    if (authorization != null ? !authorization.equals(that.authorization) :that.authorization != null) return false;
    if (basicAuth != null ? !basicAuth.equals(that.basicAuth) :that.basicAuth != null) return false;
    if (bearerToken != null ? !bearerToken.equals(that.bearerToken) :that.bearerToken != null) return false;
    if (bearerTokenFile != null ? !bearerTokenFile.equals(that.bearerTokenFile) :that.bearerTokenFile != null) return false;
    if (host != null ? !host.equals(that.host) :that.host != null) return false;
    if (tlsConfig != null ? !tlsConfig.equals(that.tlsConfig) :that.tlsConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authorization,  basicAuth,  bearerToken,  bearerTokenFile,  host,  tlsConfig,  additionalProperties,  super.hashCode());
  }
  public class AuthorizationNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.AuthorizationFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AuthorizationNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.Authorization item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder(this, item);
    }
    AuthorizationNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder builder;
    public N and() {
      return (N) APIServerConfigFluentImpl.this.withAuthorization(builder.build());
    }
    public N endAuthorization() {
      return and();
    }
    
  }
  public class BasicAuthNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.BasicAuthFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    BasicAuthNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.BasicAuth item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder(this, item);
    }
    BasicAuthNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder builder;
    public N and() {
      return (N) APIServerConfigFluentImpl.this.withBasicAuth(builder.build());
    }
    public N endBasicAuth() {
      return and();
    }
    
  }
  public class TlsConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.TLSConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder(this, item);
    }
    TlsConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder builder;
    public N and() {
      return (N) APIServerConfigFluentImpl.this.withTlsConfig(builder.build());
    }
    public N endTlsConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/APIServerConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class APIServerConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent<A>{
  public APIServerConfigFluentImpl() {
  }
  public APIServerConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.APIServerConfig instance) {
    this.withAuthorization(instance.getAuthorization()); 
    this.withBasicAuth(instance.getBasicAuth()); 
    this.withBearerToken(instance.getBearerToken()); 
    this.withBearerTokenFile(instance.getBearerTokenFile()); 
    this.withHost(instance.getHost()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder authorization;
  private io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder basicAuth;
  private java.lang.String bearerToken;
  private java.lang.String bearerTokenFile;
  private java.lang.String host;
  private io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder tlsConfig;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAuthorization instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.Authorization getAuthorization() {
    return this.authorization!=null?this.authorization.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.Authorization buildAuthorization() {
    return this.authorization!=null?this.authorization.build():null;
  }
  public A withAuthorization(io.fabric8.openshift.api.model.monitoring.v1.Authorization authorization) {
    _visitables.get("authorization").remove(this.authorization);
    if (authorization!=null){ this.authorization= new io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder(authorization); _visitables.get("authorization").add(this.authorization);} return (A) this;
  }
  public java.lang.Boolean hasAuthorization() {
    return this.authorization != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> withNewAuthorization() {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.AuthorizationNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> withNewAuthorizationLike(io.fabric8.openshift.api.model.monitoring.v1.Authorization item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.AuthorizationNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> editAuthorization() {
    return withNewAuthorizationLike(getAuthorization());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> editOrNewAuthorization() {
    return withNewAuthorizationLike(getAuthorization() != null ? getAuthorization(): new io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<A> editOrNewAuthorizationLike(io.fabric8.openshift.api.model.monitoring.v1.Authorization item) {
    return withNewAuthorizationLike(getAuthorization() != null ? getAuthorization(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildBasicAuth instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.BasicAuth getBasicAuth() {
    return this.basicAuth!=null?this.basicAuth.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.BasicAuth buildBasicAuth() {
    return this.basicAuth!=null?this.basicAuth.build():null;
  }
  public A withBasicAuth(io.fabric8.openshift.api.model.monitoring.v1.BasicAuth basicAuth) {
    _visitables.get("basicAuth").remove(this.basicAuth);
    if (basicAuth!=null){ this.basicAuth= new io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder(basicAuth); _visitables.get("basicAuth").add(this.basicAuth);} return (A) this;
  }
  public java.lang.Boolean hasBasicAuth() {
    return this.basicAuth != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> withNewBasicAuth() {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.BasicAuthNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> withNewBasicAuthLike(io.fabric8.openshift.api.model.monitoring.v1.BasicAuth item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.BasicAuthNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> editBasicAuth() {
    return withNewBasicAuthLike(getBasicAuth());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> editOrNewBasicAuth() {
    return withNewBasicAuthLike(getBasicAuth() != null ? getBasicAuth(): new io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<A> editOrNewBasicAuthLike(io.fabric8.openshift.api.model.monitoring.v1.BasicAuth item) {
    return withNewBasicAuthLike(getBasicAuth() != null ? getBasicAuth(): item);
  }
  public java.lang.String getBearerToken() {
    return this.bearerToken;
  }
  public A withBearerToken(java.lang.String bearerToken) {
    this.bearerToken=bearerToken; return (A) this;
  }
  public java.lang.Boolean hasBearerToken() {
    return this.bearerToken != null;
  }
  
  /**
   * Method is deprecated. use withBearerToken instead.
   */
  @java.lang.Deprecated
  public A withNewBearerToken(java.lang.String arg0) {
    return (A)withBearerToken(new String(arg0));
  }
  public java.lang.String getBearerTokenFile() {
    return this.bearerTokenFile;
  }
  public A withBearerTokenFile(java.lang.String bearerTokenFile) {
    this.bearerTokenFile=bearerTokenFile; return (A) this;
  }
  public java.lang.Boolean hasBearerTokenFile() {
    return this.bearerTokenFile != null;
  }
  
  /**
   * Method is deprecated. use withBearerTokenFile instead.
   */
  @java.lang.Deprecated
  public A withNewBearerTokenFile(java.lang.String arg0) {
    return (A)withBearerTokenFile(new String(arg0));
  }
  public java.lang.String getHost() {
    return this.host;
  }
  public A withHost(java.lang.String host) {
    this.host=host; return (A) this;
  }
  public java.lang.Boolean hasHost() {
    return this.host != null;
  }
  
  /**
   * Method is deprecated. use withHost instead.
   */
  @java.lang.Deprecated
  public A withNewHost(java.lang.String arg0) {
    return (A)withHost(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTlsConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig getTlsConfig() {
    return this.tlsConfig!=null?this.tlsConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig buildTlsConfig() {
    return this.tlsConfig!=null?this.tlsConfig.build():null;
  }
  public A withTlsConfig(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig tlsConfig) {
    _visitables.get("tlsConfig").remove(this.tlsConfig);
    if (tlsConfig!=null){ this.tlsConfig= new io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder(tlsConfig); _visitables.get("tlsConfig").add(this.tlsConfig);} return (A) this;
  }
  public java.lang.Boolean hasTlsConfig() {
    return this.tlsConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> withNewTlsConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.TlsConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> withNewTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluentImpl.TlsConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> editTlsConfig() {
    return withNewTlsConfigLike(getTlsConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> editOrNewTlsConfig() {
    return withNewTlsConfigLike(getTlsConfig() != null ? getTlsConfig(): new io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<A> editOrNewTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item) {
    return withNewTlsConfigLike(getTlsConfig() != null ? getTlsConfig(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    APIServerConfigFluentImpl that = (APIServerConfigFluentImpl) o;
    if (authorization != null ? !authorization.equals(that.authorization) :that.authorization != null) return false;
    if (basicAuth != null ? !basicAuth.equals(that.basicAuth) :that.basicAuth != null) return false;
    if (bearerToken != null ? !bearerToken.equals(that.bearerToken) :that.bearerToken != null) return false;
    if (bearerTokenFile != null ? !bearerTokenFile.equals(that.bearerTokenFile) :that.bearerTokenFile != null) return false;
    if (host != null ? !host.equals(that.host) :that.host != null) return false;
    if (tlsConfig != null ? !tlsConfig.equals(that.tlsConfig) :that.tlsConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authorization,  basicAuth,  bearerToken,  bearerTokenFile,  host,  tlsConfig,  additionalProperties,  super.hashCode());
  }
  public class AuthorizationNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.AuthorizationFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.AuthorizationNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AuthorizationNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.Authorization item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder(this, item);
    }
    AuthorizationNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.AuthorizationBuilder builder;
    public N and() {
      return (N) APIServerConfigFluentImpl.this.withAuthorization(builder.build());
    }
    public N endAuthorization() {
      return and();
    }
    
  }
  public class BasicAuthNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.BasicAuthFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.BasicAuthNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    BasicAuthNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.BasicAuth item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder(this, item);
    }
    BasicAuthNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.BasicAuthBuilder builder;
    public N and() {
      return (N) APIServerConfigFluentImpl.this.withBasicAuth(builder.build());
    }
    public N endBasicAuth() {
      return and();
    }
    
  }
  public class TlsConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.TLSConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.APIServerConfigFluent.TlsConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder(this, item);
    }
    TlsConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.TLSConfigBuilder builder;
    public N and() {
      return (N) APIServerConfigFluentImpl.this.withTlsConfig(builder.build());
    }
    public N endTlsConfig() {
      return and();
    }
    
  }
  
}
